@@ -1057,10 +1057,6 @@ sub _process_log_line {
             return unless $self->{'report_options'}->{'showscheduleddowntime'};
 
             $self->_log('_process_log_line() hostdowntime, inserting fake event for all hosts/services') if $verbose;
-            # set an event for all services
-            for my $service_description (keys %{$self->{'service_data'}->{$data->{'host_name'}}}) {
-                &_set_service_event($self, $data->{'host_name'}, $service_description, $result, { 'start' => $data->{'start'}, 'end' => $data->{'end'}, 'time' => $data->{'time'} });
-            }
 
             undef $data->{'state'}; # we dont know the current state, so make sure it wont be overwritten
 
@@ -1075,7 +1071,7 @@ sub _process_log_line {
                 $host_hist->{'in_downtime'} = 1;
             }
             else {
-                $start = "STOP";
+                $start = "END";
                 $plugin_output = 'End of scheduled downtime';
                 $host_hist->{'in_downtime'} = 0;
             }
@@ -1091,6 +1087,11 @@ sub _process_log_line {
                                 'host'          => $data->{'host_name'},
                             },
             );
+
+            # set an event for all services
+            for my $service_description (keys %{$self->{'service_data'}->{$data->{'host_name'}}}) {
+                &_set_service_event($self, $data->{'host_name'}, $service_description, $result, { 'start' => $data->{'start'}, 'end' => $data->{'end'}, 'time' => $data->{'time'} });
+            }
         }
         else {
             $self->_log('  -> unknown log type') if $verbose;
@@ -1153,27 +1154,27 @@ sub _set_service_event {
 
             # ok
             elsif($service_hist->{'last_state'} == STATE_OK) {
-                $self->_add_time($service_data, $data->{'time'}, 'time_ok', $diff, ($service_hist->{'in_downtime'} or $host_hist->{'in_downtime'}));
+                $self->_add_time($service_data, $data->{'time'}, 'time_ok', $diff, ($service_hist->{'in_downtime'} || $host_hist->{'in_downtime'}));
             }
 
             # warning
             elsif($service_hist->{'last_state'} == STATE_WARNING) {
-                $self->_add_time($service_data, $data->{'time'}, 'time_warning', $diff, ($service_hist->{'in_downtime'} or $host_hist->{'in_downtime'}));
+                $self->_add_time($service_data, $data->{'time'}, 'time_warning', $diff, ($service_hist->{'in_downtime'} || $host_hist->{'in_downtime'}));
             }
 
             # critical
             elsif($service_hist->{'last_state'} == STATE_CRITICAL) {
-                $self->_add_time($service_data, $data->{'time'}, 'time_critical', $diff, ($service_hist->{'in_downtime'} or $host_hist->{'in_downtime'}));
+                $self->_add_time($service_data, $data->{'time'}, 'time_critical', $diff, ($service_hist->{'in_downtime'} || $host_hist->{'in_downtime'}));
             }
 
             # unknown
             elsif($service_hist->{'last_state'} == STATE_UNKNOWN) {
-                $self->_add_time($service_data, $data->{'time'}, 'time_unknown', $diff, ($service_hist->{'in_downtime'} or $host_hist->{'in_downtime'}));
+                $self->_add_time($service_data, $data->{'time'}, 'time_unknown', $diff, ($service_hist->{'in_downtime'} || $host_hist->{'in_downtime'}));
             }
 
             # no data yet
             elsif($service_hist->{'last_state'} == STATE_UNSPECIFIED) {
-                $self->_add_time($service_data, $data->{'time'}, 'time_indeterminate_nodata', $diff, ($service_hist->{'in_downtime'} or $host_hist->{'in_downtime'}), 'scheduled_time_indeterminate');
+                $self->_add_time($service_data, $data->{'time'}, 'time_indeterminate_nodata', $diff, ($service_hist->{'in_downtime'} || $host_hist->{'in_downtime'}), 'scheduled_time_indeterminate');
             }
 
             # not running
